@@ -53,9 +53,7 @@ import Distribution.Package (Dependency(..), PackageIdentifier(..), PackageName,
 import Distribution.PackageDescription as Cabal (allBuildInfo, author, BuildInfo(buildable, extraLibs), Executable(buildInfo, exeName), FlagName, mkFlagName, unFlagName, maintainer, PackageDescription(testSuites, description))
 import Distribution.Types.UnqualComponentName
 import Distribution.PackageDescription as Cabal (PackageDescription(dataFiles, {-description,-} executables, library, package, synopsis))
-#if MIN_VERSION_Cabal(3,2,0)
 import qualified Distribution.Utils.ShortText as ST
-#endif
 import Prelude hiding (init, log, map, unlines, unlines, writeFile)
 import System.Directory (doesFileExist)
 import System.FilePath ((<.>), (</>), makeRelative, splitFileName, takeDirectory, takeFileName)
@@ -261,11 +259,7 @@ finalizeMaintainer currentUser = do
   pkgDesc <- use A.packageDescription
   maintainerOption <- use (A.debInfo . D.maintainerOption)
   uploadersOption <- use (A.debInfo . D.uploadersOption)
-#if MIN_VERSION_Cabal(3,2,0)
   let toString = ST.fromShortText
-#else
-  let toString = id
-#endif
       cabalAuthorString = takeWhile (\ c -> c /= ',' && c /= '\n') (toString (Cabal.author pkgDesc))
       cabalMaintainerString = takeWhile (\ c -> c /= ',' && c /= '\n') (toString (Cabal.maintainer pkgDesc))
       cabalMaintainerString' = cabalAuthorString <> " <" <> cabalMaintainerString <> ">"
@@ -377,11 +371,7 @@ debianDescriptionBase p =
       desc' :: [String]
       desc' = List.map addDot . stripWith List.null $ fmap (dropWhileEnd isSpace) $ lines $ toString $ Cabal.description p
       addDot line = if List.null line then "." else line
-#if MIN_VERSION_Cabal(3,2,0)
       toString = ST.fromShortText
-#else
-      toString = id
-#endif
 
 -- | Make sure there is a changelog entry with the version number and
 -- source package name implied by the debianization.  This means
